
<p align="center">
  <img src="./docs/logos/logo_scifin_github.jpg" width=300 title="hover text">
</p>



# SciFin

SciFin is a python package for Science and Finance.

## Summary

The SciFin package is a Python package designed to gather and develop methods for scientific studies and financial services. It originates from the observation that numerous methods developed in scientific fields (such as mathematics, physics, biology and climate sciences) have direct applicability in finance and that, conversely, multiple methods developed in finance can benefit science.

The development goal of this package is to offer a toolbox that can be used to derive specific applications both in research and business. Its purpose is not only to bring these fields together, but also to increase interoperability between them, helping science turn into business and finance to get new insights from science. Some functions will thus be neutral to any scientific or economic fields, while others will be more specialized for precise tasks. The motivationg behind this design is to provide tools that perform advanced tasks without depending on too many parameters.


## Contents

The current development is focused on the following topics:
- `classifier`: Classification techniques
- `fouriertrf`: Fourier transforms
- `geneticalg`: Genetic algorithms
- `marketdata`: Reading market data
- `montecarlo`: Monte Carlo simulations
- `neuralnets`: Neural networks
- `statistics`: Basic statistics
- `timeseries`: Time series analysis

Other topics will later follow.


## Installation

Installing SciFin on Linux or Mac is very easy, you can simply run `pip install SciFin` on the Terminal command line.

If you encounter problems during installation or after and think you know how the problem can be improved, please share it with me.


## Contact

- If you have comments or suggestions, you can reach Fabien Nugier.
- If you wish to contribute, please contact me through GitHub.





